MirrorDefinitionUtils class
Mirror definition judgement util.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isConstructorMethod(
MethodMirror methodMirror) → bool - Whether a constructor method.
-
isDefinitionClass(
ClassMirror classMirror) → bool - Whether a definition class
-
isDefinitionMethod(
MethodMirror methodMirror) → bool - Whether a definition method.
-
isGetterOrSetterMethod(
MethodMirror methodMirror) → bool - Whether a getter or setter method.
-
isNonVariableField(
VariableMirror variableMirror) → bool - Whether not a variable field.
-
isNotDefinitionClass(
ClassMirror classMirror) → bool - Whether not a definition class
-
isNotDefinitionMethod(
MethodMirror methodMirror) → bool - Whether not a definition method.
-
isOperatorMethod(
MethodMirror methodMirror) → bool - Whether a getter or setter method.
-
isRegularMethod(
MethodMirror methodMirror) → bool - Whether a regular method. Note that operators method is regular method.
-
isVariableField(
VariableMirror variableMirror) → bool - Whether a variable field.
-
reflect(
Reflectable reflector, Object instance) → InstanceMirror - Get instance mirror from an real object.